@@ -133,7 +133,6 @@ QString EntryInternal::name() const
 
 void EntryInternal::setName(const QString &name)
 {
-    d.detach();
     d->mName = name;
 }
 
@@ -144,7 +143,6 @@ QString EntryInternal::uniqueId() const
 
 void EntryInternal::setUniqueId(const QString &id)
 {
-    d.detach();
     d->mUniqueId = id;
 }
 
@@ -155,7 +153,6 @@ QString EntryInternal::providerId() const
 
 void EntryInternal::setProviderId(const QString &id)
 {
-    d.detach();
     d->mProviderId = id;
 }
 
@@ -166,7 +163,6 @@ QString EntryInternal::category() const
 
 void EntryInternal::setCategory(const QString &category)
 {
-    d.detach();
     d->mCategory = category;
 }
 
@@ -177,7 +173,6 @@ QUrl EntryInternal::homepage() const
 
 void EntryInternal::setHomepage(const QUrl &page)
 {
-    d.detach();
     d->mHomepage = page;
 }
 
@@ -188,7 +183,6 @@ Author EntryInternal::author() const
 
 void EntryInternal::setAuthor(const KNSCore::Author &author)
 {
-    d.detach();
     d->mAuthor = author;
 }
 
@@ -199,7 +193,6 @@ QString EntryInternal::license() const
 
 void EntryInternal::setLicense(const QString &license)
 {
-    d.detach();
     d->mLicense = license;
 }
 
@@ -210,7 +203,6 @@ QString EntryInternal::summary() const
 
 void EntryInternal::setSummary(const QString &summary)
 {
-    d.detach();
     d->mSummary = summary;
 }
 
@@ -221,13 +213,11 @@ QString EntryInternal::shortSummary() const
 
 void EntryInternal::setShortSummary(const QString &summary)
 {
-    d.detach();
     d->mShortSummary = summary;
 }
 
 void EntryInternal::setChangelog(const QString &changelog)
 {
-    d.detach();
     d->mChangelog = changelog;
 }
 
@@ -243,7 +233,6 @@ QString EntryInternal::version() const
 
 void EntryInternal::setVersion(const QString &version)
 {
-    d.detach();
     d->mVersion = version;
 }
 
@@ -254,7 +243,6 @@ QDate EntryInternal::releaseDate() const
 
 void EntryInternal::setReleaseDate(const QDate &releasedate)
 {
-    d.detach();
     d->mReleaseDate = releasedate;
 }
 
@@ -265,7 +253,6 @@ QString EntryInternal::payload() const
 
 void EntryInternal::setPayload(const QString &url)
 {
-    d.detach();
     d->mPayload = url;
 }
 
@@ -276,7 +263,6 @@ QDate EntryInternal::updateReleaseDate() const
 
 void EntryInternal::setUpdateReleaseDate(const QDate &releasedate)
 {
-    d.detach();
     d->mUpdateReleaseDate = releasedate;
 }
 
@@ -287,7 +273,6 @@ QString EntryInternal::updateVersion() const
 
 void EntryInternal::setUpdateVersion(const QString &version)
 {
-    d.detach();
     d->mUpdateVersion = version;
 }
 
@@ -298,7 +283,6 @@ QString EntryInternal::previewUrl(PreviewType type) const
 
 void EntryInternal::setPreviewUrl(const QString &url, PreviewType type)
 {
-    d.detach();
     d->mPreviewUrl[type] = url;
 }
 
@@ -309,7 +293,6 @@ QImage EntryInternal::previewImage(PreviewType type) const
 
 void EntryInternal::setPreviewImage(const QImage &image, PreviewType type)
 {
-    d.detach();
     d->mPreviewImage[type] = image;
 }
 
@@ -320,7 +303,6 @@ int EntryInternal::rating() const
 
 void EntryInternal::setRating(int rating)
 {
-    d.detach();
     d->mRating = rating;
 }
 
@@ -331,7 +313,6 @@ int EntryInternal::numberOfComments() const
 
 void EntryInternal::setNumberOfComments (int comments)
 {
-    d.detach();
     d->mNumberOfComments = comments;
 }
 
@@ -342,7 +323,6 @@ int EntryInternal::downloadCount() const
 
 void EntryInternal::setDownloadCount(int downloads)
 {
-    d.detach();
     d->mDownloadCount = downloads;
 }
 
@@ -353,7 +333,6 @@ int EntryInternal::numberFans() const
 
 void EntryInternal::setNumberFans(int fans)
 {
-    d.detach();
     d->mNumberFans = fans;
 }
 
@@ -364,7 +343,6 @@ QString EntryInternal::donationLink() const
 
 void EntryInternal::setDonationLink(const QString &link)
 {
-    d.detach();
     d->mDonationLink = link;
 }
 
@@ -374,7 +352,6 @@ int EntryInternal::numberKnowledgebaseEntries() const
 }
 void EntryInternal::setNumberKnowledgebaseEntries(int num)
 {
-    d.detach();
     d->mNumberKnowledgebaseEntries = num;
 }
 
@@ -384,7 +361,6 @@ QString EntryInternal::knowledgebaseLink() const
 }
 void EntryInternal::setKnowledgebaseLink(const QString &link)
 {
-    d.detach();
     d->mKnowledgebaseLink = link;
 }
 
@@ -409,7 +385,6 @@ EntryInternal::Source EntryInternal::source() const
 
 void EntryInternal::setSource(Source source)
 {
-    d.detach();
     d->mSource = source;
 }
 
@@ -420,13 +395,11 @@ KNS3::Entry::Status EntryInternal::status() const
 
 void EntryInternal::setStatus(KNS3::Entry::Status status)
 {
-    d.detach();
     d->mStatus = status;
 }
 
 void KNSCore::EntryInternal::setInstalledFiles(const QStringList &files)
 {
-    d.detach();
     d->mInstalledFiles = files;
 }
 
@@ -437,7 +410,6 @@ QStringList KNSCore::EntryInternal::installedFiles() const
 
 void KNSCore::EntryInternal::setUnInstalledFiles(const QStringList &files)
 {
-    d.detach();
     d->mUnInstalledFiles = files;
 }
 
@@ -458,13 +430,11 @@ QList<KNSCore::EntryInternal::DownloadLinkInformation> KNSCore::EntryInternal::d
 
 void KNSCore::EntryInternal::appendDownloadLinkInformation(const KNSCore::EntryInternal::DownloadLinkInformation &info)
 {
-    d.detach();
     d->mDownloadLinkInformationList.append(info);
 }
 
 void EntryInternal::clearDownloadLinkInformation()
 {
-    d.detach();
     d->mDownloadLinkInformationList.clear();
 }
 
@@ -510,13 +480,12 @@ static int readInt(QXmlStreamReader* xml)
 
 bool KNSCore::EntryInternal::setEntryXML(QXmlStreamReader& reader)
 {
-    d.detach();
     if (reader.name() != QLatin1String("stuff")) {
         qWarning() << "Parsing Entry from invalid XML";
         return false;
     }
 
-    d->mCategory = reader.attributes().value("category").toString();
+    d->mCategory = reader.attributes().value(QStringLiteral("category")).toString();
 
     while (!reader.atEnd()) {
         const auto token = readNextSkipComments(&reader);
@@ -608,7 +577,6 @@ bool KNSCore::EntryInternal::setEntryXML(QXmlStreamReader& reader)
 
 bool KNSCore::EntryInternal::setEntryXML(const QDomElement &xmldata)
 {
-    d.detach();
     if (xmldata.tagName() != QLatin1String("stuff")) {
         qWarning() << "Parsing Entry from invalid XML";
         return false;
